Authors
=======

``mutatest`` is written and maintained by Evan Kepner.

See the `Contributing Guidelines <https://mutatest.readthedocs.io/en/latest/contributing.html>`_ if you
are interested in submitting code in the form of pull requests.
Contributors are listed here, and can be seen on the
`GitHub contribution graph <https://github.com/EvanKepner/mutatest/graphs/contributors>`_.

Contributors
------------

* David Li-Bland
